@@ -5,7 +5,9 @@ import nacl.secret
 
 
 def encrypt(data, *, password):
-    secret_key = nacl.hash.sha256(password.encode('utf-8'), encoder=nacl.encoding.RawEncoder)
+    secret_key = nacl.hash.sha256(
+        password.encode("utf-8"), encoder=nacl.encoding.RawEncoder
+    )
     secret_box = nacl.secret.SecretBox(secret_key)
     encrypted_data = secret_box.encrypt(data)
     del secret_key, secret_box
@@ -13,7 +15,9 @@ def encrypt(data, *, password):
 
 
 def decrypt(data, *, password):
-    secret_key = nacl.hash.sha256(password.encode('utf-8'), encoder=nacl.encoding.RawEncoder)
+    secret_key = nacl.hash.sha256(
+        password.encode("utf-8"), encoder=nacl.encoding.RawEncoder
+    )
     secret_box = nacl.secret.SecretBox(secret_key)
     plain_text = secret_box.decrypt(data)
     del secret_key, secret_box
